==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexfileexporterbibtex.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBIBTEXFILEEXPORTERBIBTEX_H
#define BIBTEXBIBTEXFILEEXPORTERBIBTEX_H

#include <bibtexelement.h>
#include <bibtexentryfield.h>
#include <bibtexfileexporter.h>

class QChar;

namespace BibTeX
{
    class BibTeXComment;

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporterBibTeX : public BibTeXFileExporter
    {
    public:
        BibTeXFileExporterBibTeX();
        ~BibTeXFileExporterBibTeX();

        bool save( QIODevice* iodevice, BibTeXFile* bibtexfile );
        bool save( QIODevice* iodevice, BibTeXElement* element );

        void setStringDelimiter( const QChar& stringOpenDelimiter, const QChar& stringCloseDelimiter );

    public slots:
        void cancel();

    private:
        QChar m_stringOpenDelimiter;
        QChar m_stringCloseDelimiter;
        bool cancelFlag;

        bool writeEntry( QTextStream &stream, BibTeXEntry* entry );
        bool writeString( QTextStream &stream, BibTeXString *string );
        bool writeComment( QTextStream &stream, BibTeXComment *comment );
        bool writePreamble( QTextStream &stream, const QString& preamble );

        QString itemToString( const BibTeXElement::FieldItems::iterator& begin, const BibTeXElement::FieldItems::iterator& end, const BibTeXEntryField::FieldType fieldType = BibTeXEntryField::ftUnknown );
    };

}

#endif

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/bibtexfileexporterbibtex.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBIBTEXFILEEXPORTERBIBTEX_H
#define BIBTEXBIBTEXFILEEXPORTERBIBTEX_H

#include <bibtexelement.h>
#include <bibtexentryfield.h>
#include <bibtexfileexporter.h>

class QChar;

namespace BibTeX
{
    class BibTeXComment;

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporterBibTeX : public BibTeXFileExporter
    {
    public:
        BibTeXFileExporterBibTeX();
        ~BibTeXFileExporterBibTeX();

        bool save( QIODevice* iodevice, BibTeXFile* bibtexfile, QStringList *errorLog = NULL );
        bool save( QIODevice* iodevice, BibTeXElement* element, QStringList *errorLog = NULL );

        void setStringDelimiter( const QChar& stringOpenDelimiter, const QChar& stringCloseDelimiter );
        void setEncoding( BibTeXFile::Encoding encoding );

    public slots:
        void cancel();

    private:
        QChar m_stringOpenDelimiter;
        QChar m_stringCloseDelimiter;
        BibTeXFile::Encoding m_encoding;
        bool cancelFlag;

        bool writeEntry( QTextStream &stream, BibTeXEntry* entry );
        bool writeString( QTextStream &stream, BibTeXString *string );
        bool writeComment( QTextStream &stream, BibTeXComment *comment );
        bool writePreamble( QTextStream &stream, const QString& preamble );

        QString valueToString( const BibTeXValue *value, const BibTeXEntryField::FieldType fieldType = BibTeXEntryField::ftUnknown );
    };

}

#endif
